import { AbstractRepository } from '@crosslab/service-common';
import { WEEK } from '../../../globals.js';
import { calculateAvailability } from '../../../methods/availability.js';
import { ConcreteDeviceModel } from '../../model.js';
export class ConcreteDeviceRepository extends AbstractRepository {
    dependencies = {};
    constructor() {
        super('Concrete Device');
    }
    dependenciesMet() {
        if (!this.dependencies.deviceOverview)
            return false;
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(ConcreteDeviceModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.type = 'device';
        model.availabilityRules = [];
        model.connected = false;
        model.services = [];
        return model;
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        await this.dependencies.deviceOverview.write(model, data);
        if (data.experiment)
            model.experiment = data.experiment;
        if (data.services)
            model.services = data.services;
    }
    async format(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        return {
            ...(await this.dependencies.deviceOverview.format(model)),
            type: 'device',
            announcedAvailability: calculateAvailability(model.availabilityRules, Date.now(), Date.now() + WEEK),
            connected: model.connected,
            experiment: model.experiment ?? undefined,
            services: model.services,
        };
    }
}
//# sourceMappingURL=concreteDevice.js.map